SwipeAction class

Constructors

SwipeAction({required SwipeActionOnTapCallback onTap, String? title, TextStyle style = const TextStyle(fontSize: 18, color: Colors.white), Color color = Colors.red, Widget? icon, bool closeOnTap = true, double backgroundRadius = 0.0, bool forceAlignmentToBoundary = false, double widthSpace = 80, SwipeNestedAction? nestedAction, Widget? content, bool performsFirstActionWithFullSwipe = false})
const

Properties

backgroundRadius → double
背景左上(右上)和左下(左上)的圆角
final
closeOnTap → bool
close the actions button after you tap it,default value is true
final
color → Color
bg color
final
content → Widget?
If you want to customize your content,you can use this attr. And don't set title and icon attrs
final
forceAlignmentToBoundary → bool
When you have just one button,if it is on leading/trailing,set this param to true will make the content inside button Alignment.centerRight / Alignment.centerLeft
final
hashCode → int
The hash code for this object.
no setterinherited
icon → Widget?
图标
final
nestedAction → SwipeNestedAction?
嵌套的action
final
onTap → SwipeActionOnTapCallback
onTap callback
final
performsFirstActionWithFullSwipe → bool
Tip:It is ok to set this property only in first action. When drag cell a long distance,it will be dismissed, and it will execute the onTap of the first SwipeAction def value = false
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → TextStyle
title's text Style default value is :TextStyle(fontSize: 18,color: Colors.white)
final
title → String?
标题
final
widthSpace → double
The width space this action button will take when opening.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited