SwipeActionCellState class

Inheritance
Mixed-in types

Constructors

SwipeActionCellState()

Properties

animation ↔ Animation<double>
getter/setter pair
changeEditingModeSubscription ↔ StreamSubscription?
getter/setter pair
closeCurvedAnim ↔ Animation<double>
getter/setter pair
context → BuildContext
The location in the tree where this widget builds.
no setterinherited
controller ↔ AnimationController
getter/setter pair
currentOffset ↔ Offset
getter/setter pair
deleteController ↔ AnimationController
getter/setter pair
deleteCurvedAnim ↔ Animation<double>
getter/setter pair
editController ↔ AnimationController
getter/setter pair
editCurvedAnim ↔ Animation<double>
getter/setter pair
editing ↔ bool
getter/setter pair
gestures → Map<Type, GestureRecognizerFactory<GestureRecognizer>>
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasLeadingAction → bool
no setter
hasTrailingAction → bool
no setter
ignoreActionButtonHit ↔ bool
bool field to avoid action button be tapped open when cell is closing
getter/setter pair
ignorePointer ↔ bool
getter/setter pair
ignorePointerSubscription ↔ StreamSubscription?
getter/setter pair
lastItemOut ↔ bool
getter/setter pair
leadingActionsCount → int
no setter
lockAnim ↔ bool
getter/setter pair
maxLeadingPullWidth ↔ double
getter/setter pair
maxTrailingPullWidth ↔ double
getter/setter pair
mounted → bool
Whether this State object is currently in a tree.
no setterinherited
openCurvedAnim ↔ Animation<double>
getter/setter pair
otherCellOpenEventSubscription ↔ StreamSubscription?
getter/setter pair
programOpenCellEventSubscription ↔ StreamSubscription?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollPosition ↔ ScrollPosition?
getter/setter pair
selected ↔ bool
getter/setter pair
selectedSubscription ↔ StreamSubscription?
getter/setter pair
trailingActionsCount → int
no setter
whenLeadingActionShowing ↔ bool
getter/setter pair
whenTrailingActionShowing ↔ bool
getter/setter pair
widget → SwipeActionCell
The current configuration.
no setterinherited
width ↔ double
getter/setter pair

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
adjustOffset({required double offsetX, required Curve curve, required bool trailing}) → void
When nestedAction is open ,adjust currentOffset if nestedWidth > currentOffset
build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
closeWithAnim({double? end}) → Future<void>
close this cell and return the Future of the animation
createTicker(TickerCallback onTick) → Ticker
Creates a ticker with the given callback.
inherited
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
deleteWithAnim() → Future<void>
delete this cell and return the Future of the animation
didChangeDependencies() → void
Called when a dependency of this State object changes.
override
didUpdateWidget(covariant SwipeActionCell oldWidget) → void
Called whenever the widget configuration changes.
override
dispose() → void
Called when this object is removed from the tree permanently.
override
initState() → void
Called when this object is inserted into the tree.
override
modifyOffsetIfOverScrolled() → void
modify the offset if over scrolled
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
resetWithAni({int? milisecond}) → Future<void>
close this cell and return the Future of the animation
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited